@@ -1,7 +1,7 @@
 """
 Type annotations for comprehend service literal definitions.
 
-[Open documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_comprehend/literals.html)
+[Open documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_comprehend/literals/)
 
 Usage::
 
@@ -48,8 +48,11 @@ __all__ = (
     "SentimentTypeType",
     "SplitType",
     "SyntaxLanguageCodeType",
+    "ComprehendServiceName",
     "ServiceName",
+    "ResourceServiceName",
     "PaginatorName",
+    "RegionName",
 )
 
 
@@ -142,6 +145,7 @@ PiiEntityTypeType = Literal[
 SentimentTypeType = Literal["MIXED", "NEGATIVE", "NEUTRAL", "POSITIVE"]
 SplitType = Literal["TEST", "TRAIN"]
 SyntaxLanguageCodeType = Literal["de", "en", "es", "fr", "it", "pt"]
+ComprehendServiceName = Literal["comprehend"]
 ServiceName = Literal[
     "accessanalyzer",
     "account",
@@ -173,6 +177,7 @@ ServiceName = Literal[
     "backup",
     "backup-gateway",
     "batch",
+    "billingconductor",
     "braket",
     "budgets",
     "ce",
@@ -259,6 +264,7 @@ ServiceName = Literal[
     "frauddetector",
     "fsx",
     "gamelift",
+    "gamesparks",
     "glacier",
     "globalaccelerator",
     "glue",
@@ -295,6 +301,7 @@ ServiceName = Literal[
     "kafka",
     "kafkaconnect",
     "kendra",
+    "keyspaces",
     "kinesis",
     "kinesis-video-archived-media",
     "kinesis-video-media",
@@ -443,6 +450,18 @@ ServiceName = Literal[
     "workspaces-web",
     "xray",
 ]
+ResourceServiceName = Literal[
+    "cloudformation",
+    "cloudwatch",
+    "dynamodb",
+    "ec2",
+    "glacier",
+    "iam",
+    "opsworks",
+    "s3",
+    "sns",
+    "sqs",
+]
 PaginatorName = Literal[
     "list_document_classification_jobs",
     "list_document_classifiers",
@@ -453,3 +472,17 @@ PaginatorName = Literal[
     "list_sentiment_detection_jobs",
     "list_topics_detection_jobs",
 ]
+RegionName = Literal[
+    "ap-northeast-1",
+    "ap-northeast-2",
+    "ap-south-1",
+    "ap-southeast-1",
+    "ap-southeast-2",
+    "ca-central-1",
+    "eu-central-1",
+    "eu-west-1",
+    "eu-west-2",
+    "us-east-1",
+    "us-east-2",
+    "us-west-2",
+]
