@@ -1,7 +1,7 @@
 """
 Type annotations for comprehend service type definitions.
 
-[Open documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_comprehend/type_defs.html)
+[Open documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_comprehend/type_defs/)
 
 Usage::
 
@@ -15,6 +15,8 @@ import sys
 from datetime import datetime
 from typing import Dict, List, Sequence, Union
 
+from typing_extensions import NotRequired
+
 from .literals import (
     AugmentedManifestsDocumentTypeFormatType,
     DocumentClassifierDataFormatType,
@@ -77,6 +79,7 @@ __all__ = (
     "DeleteDocumentClassifierRequestRequestTypeDef",
     "DeleteEndpointRequestRequestTypeDef",
     "DeleteEntityRecognizerRequestRequestTypeDef",
+    "DeleteResourcePolicyRequestRequestTypeDef",
     "DescribeDocumentClassificationJobRequestRequestTypeDef",
     "DescribeDocumentClassificationJobResponseTypeDef",
     "DescribeDocumentClassifierRequestRequestTypeDef",
@@ -95,8 +98,12 @@ __all__ = (
     "DescribeKeyPhrasesDetectionJobResponseTypeDef",
     "DescribePiiEntitiesDetectionJobRequestRequestTypeDef",
     "DescribePiiEntitiesDetectionJobResponseTypeDef",
+    "DescribeResourcePolicyRequestRequestTypeDef",
+    "DescribeResourcePolicyResponseTypeDef",
     "DescribeSentimentDetectionJobRequestRequestTypeDef",
     "DescribeSentimentDetectionJobResponseTypeDef",
+    "DescribeTargetedSentimentDetectionJobRequestRequestTypeDef",
+    "DescribeTargetedSentimentDetectionJobResponseTypeDef",
     "DescribeTopicsDetectionJobRequestRequestTypeDef",
     "DescribeTopicsDetectionJobResponseTypeDef",
     "DetectDominantLanguageRequestRequestTypeDef",
@@ -144,36 +151,48 @@ __all__ = (
     "EntityTypesListItemTypeDef",
     "EventsDetectionJobFilterTypeDef",
     "EventsDetectionJobPropertiesTypeDef",
+    "ImportModelRequestRequestTypeDef",
+    "ImportModelResponseTypeDef",
     "InputDataConfigTypeDef",
     "KeyPhraseTypeDef",
     "KeyPhrasesDetectionJobFilterTypeDef",
     "KeyPhrasesDetectionJobPropertiesTypeDef",
+    "ListDocumentClassificationJobsRequestListDocumentClassificationJobsPaginateTypeDef",
     "ListDocumentClassificationJobsRequestRequestTypeDef",
     "ListDocumentClassificationJobsResponseTypeDef",
     "ListDocumentClassifierSummariesRequestRequestTypeDef",
     "ListDocumentClassifierSummariesResponseTypeDef",
+    "ListDocumentClassifiersRequestListDocumentClassifiersPaginateTypeDef",
     "ListDocumentClassifiersRequestRequestTypeDef",
     "ListDocumentClassifiersResponseTypeDef",
+    "ListDominantLanguageDetectionJobsRequestListDominantLanguageDetectionJobsPaginateTypeDef",
     "ListDominantLanguageDetectionJobsRequestRequestTypeDef",
     "ListDominantLanguageDetectionJobsResponseTypeDef",
     "ListEndpointsRequestRequestTypeDef",
     "ListEndpointsResponseTypeDef",
+    "ListEntitiesDetectionJobsRequestListEntitiesDetectionJobsPaginateTypeDef",
     "ListEntitiesDetectionJobsRequestRequestTypeDef",
     "ListEntitiesDetectionJobsResponseTypeDef",
     "ListEntityRecognizerSummariesRequestRequestTypeDef",
     "ListEntityRecognizerSummariesResponseTypeDef",
+    "ListEntityRecognizersRequestListEntityRecognizersPaginateTypeDef",
     "ListEntityRecognizersRequestRequestTypeDef",
     "ListEntityRecognizersResponseTypeDef",
     "ListEventsDetectionJobsRequestRequestTypeDef",
     "ListEventsDetectionJobsResponseTypeDef",
+    "ListKeyPhrasesDetectionJobsRequestListKeyPhrasesDetectionJobsPaginateTypeDef",
     "ListKeyPhrasesDetectionJobsRequestRequestTypeDef",
     "ListKeyPhrasesDetectionJobsResponseTypeDef",
     "ListPiiEntitiesDetectionJobsRequestRequestTypeDef",
     "ListPiiEntitiesDetectionJobsResponseTypeDef",
+    "ListSentimentDetectionJobsRequestListSentimentDetectionJobsPaginateTypeDef",
     "ListSentimentDetectionJobsRequestRequestTypeDef",
     "ListSentimentDetectionJobsResponseTypeDef",
     "ListTagsForResourceRequestRequestTypeDef",
     "ListTagsForResourceResponseTypeDef",
+    "ListTargetedSentimentDetectionJobsRequestRequestTypeDef",
+    "ListTargetedSentimentDetectionJobsResponseTypeDef",
+    "ListTopicsDetectionJobsRequestListTopicsDetectionJobsPaginateTypeDef",
     "ListTopicsDetectionJobsRequestRequestTypeDef",
     "ListTopicsDetectionJobsResponseTypeDef",
     "OutputDataConfigTypeDef",
@@ -183,6 +202,8 @@ __all__ = (
     "PiiEntitiesDetectionJobPropertiesTypeDef",
     "PiiEntityTypeDef",
     "PiiOutputDataConfigTypeDef",
+    "PutResourcePolicyRequestRequestTypeDef",
+    "PutResourcePolicyResponseTypeDef",
     "RedactionConfigTypeDef",
     "ResponseMetadataTypeDef",
     "SentimentDetectionJobFilterTypeDef",
@@ -202,6 +223,8 @@ __all__ = (
     "StartPiiEntitiesDetectionJobResponseTypeDef",
     "StartSentimentDetectionJobRequestRequestTypeDef",
     "StartSentimentDetectionJobResponseTypeDef",
+    "StartTargetedSentimentDetectionJobRequestRequestTypeDef",
+    "StartTargetedSentimentDetectionJobResponseTypeDef",
     "StartTopicsDetectionJobRequestRequestTypeDef",
     "StartTopicsDetectionJobResponseTypeDef",
     "StopDominantLanguageDetectionJobRequestRequestTypeDef",
@@ -216,11 +239,15 @@ __all__ = (
     "StopPiiEntitiesDetectionJobResponseTypeDef",
     "StopSentimentDetectionJobRequestRequestTypeDef",
     "StopSentimentDetectionJobResponseTypeDef",
+    "StopTargetedSentimentDetectionJobRequestRequestTypeDef",
+    "StopTargetedSentimentDetectionJobResponseTypeDef",
     "StopTrainingDocumentClassifierRequestRequestTypeDef",
     "StopTrainingEntityRecognizerRequestRequestTypeDef",
     "SyntaxTokenTypeDef",
     "TagResourceRequestRequestTypeDef",
     "TagTypeDef",
+    "TargetedSentimentDetectionJobFilterTypeDef",
+    "TargetedSentimentDetectionJobPropertiesTypeDef",
     "TopicsDetectionJobFilterTypeDef",
     "TopicsDetectionJobPropertiesTypeDef",
     "UntagResourceRequestRequestTypeDef",
@@ -472,6 +499,7 @@ _OptionalCreateDocumentClassifierRequestRequestTypeDef = TypedDict(
         "VpcConfig": "VpcConfigTypeDef",
         "Mode": DocumentClassifierModeType,
         "ModelKmsKeyId": str,
+        "ModelPolicy": str,
     },
     total=False,
 )
@@ -543,6 +571,7 @@ _OptionalCreateEntityRecognizerRequestRequestTypeDef = TypedDict(
         "VolumeKmsKeyId": str,
         "VpcConfig": "VpcConfigTypeDef",
         "ModelKmsKeyId": str,
+        "ModelPolicy": str,
     },
     total=False,
 )
@@ -584,6 +613,28 @@ DeleteEntityRecognizerRequestRequestTypeDef = TypedDict(
     },
 )
 
+_RequiredDeleteResourcePolicyRequestRequestTypeDef = TypedDict(
+    "_RequiredDeleteResourcePolicyRequestRequestTypeDef",
+    {
+        "ResourceArn": str,
+    },
+)
+_OptionalDeleteResourcePolicyRequestRequestTypeDef = TypedDict(
+    "_OptionalDeleteResourcePolicyRequestRequestTypeDef",
+    {
+        "PolicyRevisionId": str,
+    },
+    total=False,
+)
+
+
+class DeleteResourcePolicyRequestRequestTypeDef(
+    _RequiredDeleteResourcePolicyRequestRequestTypeDef,
+    _OptionalDeleteResourcePolicyRequestRequestTypeDef,
+):
+    pass
+
+
 DescribeDocumentClassificationJobRequestRequestTypeDef = TypedDict(
     "DescribeDocumentClassificationJobRequestRequestTypeDef",
     {
@@ -719,6 +770,24 @@ DescribePiiEntitiesDetectionJobResponseTypeDef = TypedDict(
     },
 )
 
+DescribeResourcePolicyRequestRequestTypeDef = TypedDict(
+    "DescribeResourcePolicyRequestRequestTypeDef",
+    {
+        "ResourceArn": str,
+    },
+)
+
+DescribeResourcePolicyResponseTypeDef = TypedDict(
+    "DescribeResourcePolicyResponseTypeDef",
+    {
+        "ResourcePolicy": str,
+        "CreationTime": datetime,
+        "LastModifiedTime": datetime,
+        "PolicyRevisionId": str,
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
+
 DescribeSentimentDetectionJobRequestRequestTypeDef = TypedDict(
     "DescribeSentimentDetectionJobRequestRequestTypeDef",
     {
@@ -734,6 +803,21 @@ DescribeSentimentDetectionJobResponseTypeDef = TypedDict(
     },
 )
 
+DescribeTargetedSentimentDetectionJobRequestRequestTypeDef = TypedDict(
+    "DescribeTargetedSentimentDetectionJobRequestRequestTypeDef",
+    {
+        "JobId": str,
+    },
+)
+
+DescribeTargetedSentimentDetectionJobResponseTypeDef = TypedDict(
+    "DescribeTargetedSentimentDetectionJobResponseTypeDef",
+    {
+        "TargetedSentimentDetectionJobProperties": "TargetedSentimentDetectionJobPropertiesTypeDef",
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
+
 DescribeTopicsDetectionJobRequestRequestTypeDef = TypedDict(
     "DescribeTopicsDetectionJobRequestRequestTypeDef",
     {
@@ -951,6 +1035,7 @@ DocumentClassifierPropertiesTypeDef = TypedDict(
         "Mode": DocumentClassifierModeType,
         "ModelKmsKeyId": str,
         "VersionName": str,
+        "SourceModelArn": str,
     },
     total=False,
 )
@@ -1242,6 +1327,7 @@ EntityRecognizerPropertiesTypeDef = TypedDict(
         "VpcConfig": "VpcConfigTypeDef",
         "ModelKmsKeyId": str,
         "VersionName": str,
+        "SourceModelArn": str,
     },
     total=False,
 )
@@ -1317,6 +1403,39 @@ EventsDetectionJobPropertiesTypeDef = TypedDict(
     total=False,
 )
 
+_RequiredImportModelRequestRequestTypeDef = TypedDict(
+    "_RequiredImportModelRequestRequestTypeDef",
+    {
+        "SourceModelArn": str,
+    },
+)
+_OptionalImportModelRequestRequestTypeDef = TypedDict(
+    "_OptionalImportModelRequestRequestTypeDef",
+    {
+        "ModelName": str,
+        "VersionName": str,
+        "ModelKmsKeyId": str,
+        "DataAccessRoleArn": str,
+        "Tags": Sequence["TagTypeDef"],
+    },
+    total=False,
+)
+
+
+class ImportModelRequestRequestTypeDef(
+    _RequiredImportModelRequestRequestTypeDef, _OptionalImportModelRequestRequestTypeDef
+):
+    pass
+
+
+ImportModelResponseTypeDef = TypedDict(
+    "ImportModelResponseTypeDef",
+    {
+        "ModelArn": str,
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
+
 _RequiredInputDataConfigTypeDef = TypedDict(
     "_RequiredInputDataConfigTypeDef",
     {
@@ -1379,6 +1498,15 @@ KeyPhrasesDetectionJobPropertiesTypeDef = TypedDict(
     total=False,
 )
 
+ListDocumentClassificationJobsRequestListDocumentClassificationJobsPaginateTypeDef = TypedDict(
+    "ListDocumentClassificationJobsRequestListDocumentClassificationJobsPaginateTypeDef",
+    {
+        "Filter": "DocumentClassificationJobFilterTypeDef",
+        "PaginationConfig": "PaginatorConfigTypeDef",
+    },
+    total=False,
+)
+
 ListDocumentClassificationJobsRequestRequestTypeDef = TypedDict(
     "ListDocumentClassificationJobsRequestRequestTypeDef",
     {
@@ -1418,6 +1546,15 @@ ListDocumentClassifierSummariesResponseTypeDef = TypedDict(
     },
 )
 
+ListDocumentClassifiersRequestListDocumentClassifiersPaginateTypeDef = TypedDict(
+    "ListDocumentClassifiersRequestListDocumentClassifiersPaginateTypeDef",
+    {
+        "Filter": "DocumentClassifierFilterTypeDef",
+        "PaginationConfig": "PaginatorConfigTypeDef",
+    },
+    total=False,
+)
+
 ListDocumentClassifiersRequestRequestTypeDef = TypedDict(
     "ListDocumentClassifiersRequestRequestTypeDef",
     {
@@ -1437,6 +1574,17 @@ ListDocumentClassifiersResponseTypeDef = TypedDict(
     },
 )
 
+ListDominantLanguageDetectionJobsRequestListDominantLanguageDetectionJobsPaginateTypeDef = (
+    TypedDict(
+        "ListDominantLanguageDetectionJobsRequestListDominantLanguageDetectionJobsPaginateTypeDef",
+        {
+            "Filter": "DominantLanguageDetectionJobFilterTypeDef",
+            "PaginationConfig": "PaginatorConfigTypeDef",
+        },
+        total=False,
+    )
+)
+
 ListDominantLanguageDetectionJobsRequestRequestTypeDef = TypedDict(
     "ListDominantLanguageDetectionJobsRequestRequestTypeDef",
     {
@@ -1477,6 +1625,15 @@ ListEndpointsResponseTypeDef = TypedDict(
     },
 )
 
+ListEntitiesDetectionJobsRequestListEntitiesDetectionJobsPaginateTypeDef = TypedDict(
+    "ListEntitiesDetectionJobsRequestListEntitiesDetectionJobsPaginateTypeDef",
+    {
+        "Filter": "EntitiesDetectionJobFilterTypeDef",
+        "PaginationConfig": "PaginatorConfigTypeDef",
+    },
+    total=False,
+)
+
 ListEntitiesDetectionJobsRequestRequestTypeDef = TypedDict(
     "ListEntitiesDetectionJobsRequestRequestTypeDef",
     {
@@ -1514,6 +1671,15 @@ ListEntityRecognizerSummariesResponseTypeDef = TypedDict(
     },
 )
 
+ListEntityRecognizersRequestListEntityRecognizersPaginateTypeDef = TypedDict(
+    "ListEntityRecognizersRequestListEntityRecognizersPaginateTypeDef",
+    {
+        "Filter": "EntityRecognizerFilterTypeDef",
+        "PaginationConfig": "PaginatorConfigTypeDef",
+    },
+    total=False,
+)
+
 ListEntityRecognizersRequestRequestTypeDef = TypedDict(
     "ListEntityRecognizersRequestRequestTypeDef",
     {
@@ -1552,6 +1718,15 @@ ListEventsDetectionJobsResponseTypeDef = TypedDict(
     },
 )
 
+ListKeyPhrasesDetectionJobsRequestListKeyPhrasesDetectionJobsPaginateTypeDef = TypedDict(
+    "ListKeyPhrasesDetectionJobsRequestListKeyPhrasesDetectionJobsPaginateTypeDef",
+    {
+        "Filter": "KeyPhrasesDetectionJobFilterTypeDef",
+        "PaginationConfig": "PaginatorConfigTypeDef",
+    },
+    total=False,
+)
+
 ListKeyPhrasesDetectionJobsRequestRequestTypeDef = TypedDict(
     "ListKeyPhrasesDetectionJobsRequestRequestTypeDef",
     {
@@ -1590,6 +1765,15 @@ ListPiiEntitiesDetectionJobsResponseTypeDef = TypedDict(
     },
 )
 
+ListSentimentDetectionJobsRequestListSentimentDetectionJobsPaginateTypeDef = TypedDict(
+    "ListSentimentDetectionJobsRequestListSentimentDetectionJobsPaginateTypeDef",
+    {
+        "Filter": "SentimentDetectionJobFilterTypeDef",
+        "PaginationConfig": "PaginatorConfigTypeDef",
+    },
+    total=False,
+)
+
 ListSentimentDetectionJobsRequestRequestTypeDef = TypedDict(
     "ListSentimentDetectionJobsRequestRequestTypeDef",
     {
@@ -1625,6 +1809,36 @@ ListTagsForResourceResponseTypeDef = TypedDict(
     },
 )
 
+ListTargetedSentimentDetectionJobsRequestRequestTypeDef = TypedDict(
+    "ListTargetedSentimentDetectionJobsRequestRequestTypeDef",
+    {
+        "Filter": "TargetedSentimentDetectionJobFilterTypeDef",
+        "NextToken": str,
+        "MaxResults": int,
+    },
+    total=False,
+)
+
+ListTargetedSentimentDetectionJobsResponseTypeDef = TypedDict(
+    "ListTargetedSentimentDetectionJobsResponseTypeDef",
+    {
+        "TargetedSentimentDetectionJobPropertiesList": List[
+            "TargetedSentimentDetectionJobPropertiesTypeDef"
+        ],
+        "NextToken": str,
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
+
+ListTopicsDetectionJobsRequestListTopicsDetectionJobsPaginateTypeDef = TypedDict(
+    "ListTopicsDetectionJobsRequestListTopicsDetectionJobsPaginateTypeDef",
+    {
+        "Filter": "TopicsDetectionJobFilterTypeDef",
+        "PaginationConfig": "PaginatorConfigTypeDef",
+    },
+    total=False,
+)
+
 ListTopicsDetectionJobsRequestRequestTypeDef = TypedDict(
     "ListTopicsDetectionJobsRequestRequestTypeDef",
     {
@@ -1745,6 +1959,36 @@ class PiiOutputDataConfigTypeDef(
     pass
 
 
+_RequiredPutResourcePolicyRequestRequestTypeDef = TypedDict(
+    "_RequiredPutResourcePolicyRequestRequestTypeDef",
+    {
+        "ResourceArn": str,
+        "ResourcePolicy": str,
+    },
+)
+_OptionalPutResourcePolicyRequestRequestTypeDef = TypedDict(
+    "_OptionalPutResourcePolicyRequestRequestTypeDef",
+    {
+        "PolicyRevisionId": str,
+    },
+    total=False,
+)
+
+
+class PutResourcePolicyRequestRequestTypeDef(
+    _RequiredPutResourcePolicyRequestRequestTypeDef, _OptionalPutResourcePolicyRequestRequestTypeDef
+):
+    pass
+
+
+PutResourcePolicyResponseTypeDef = TypedDict(
+    "PutResourcePolicyResponseTypeDef",
+    {
+        "PolicyRevisionId": str,
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
+
 RedactionConfigTypeDef = TypedDict(
     "RedactionConfigTypeDef",
     {
@@ -2080,6 +2324,45 @@ StartSentimentDetectionJobResponseTypeDef = TypedDict(
     },
 )
 
+_RequiredStartTargetedSentimentDetectionJobRequestRequestTypeDef = TypedDict(
+    "_RequiredStartTargetedSentimentDetectionJobRequestRequestTypeDef",
+    {
+        "InputDataConfig": "InputDataConfigTypeDef",
+        "OutputDataConfig": "OutputDataConfigTypeDef",
+        "DataAccessRoleArn": str,
+        "LanguageCode": LanguageCodeType,
+    },
+)
+_OptionalStartTargetedSentimentDetectionJobRequestRequestTypeDef = TypedDict(
+    "_OptionalStartTargetedSentimentDetectionJobRequestRequestTypeDef",
+    {
+        "JobName": str,
+        "ClientRequestToken": str,
+        "VolumeKmsKeyId": str,
+        "VpcConfig": "VpcConfigTypeDef",
+        "Tags": Sequence["TagTypeDef"],
+    },
+    total=False,
+)
+
+
+class StartTargetedSentimentDetectionJobRequestRequestTypeDef(
+    _RequiredStartTargetedSentimentDetectionJobRequestRequestTypeDef,
+    _OptionalStartTargetedSentimentDetectionJobRequestRequestTypeDef,
+):
+    pass
+
+
+StartTargetedSentimentDetectionJobResponseTypeDef = TypedDict(
+    "StartTargetedSentimentDetectionJobResponseTypeDef",
+    {
+        "JobId": str,
+        "JobArn": str,
+        "JobStatus": JobStatusType,
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
+
 _RequiredStartTopicsDetectionJobRequestRequestTypeDef = TypedDict(
     "_RequiredStartTopicsDetectionJobRequestRequestTypeDef",
     {
@@ -2215,6 +2498,22 @@ StopSentimentDetectionJobResponseTypeDef = TypedDict(
     },
 )
 
+StopTargetedSentimentDetectionJobRequestRequestTypeDef = TypedDict(
+    "StopTargetedSentimentDetectionJobRequestRequestTypeDef",
+    {
+        "JobId": str,
+    },
+)
+
+StopTargetedSentimentDetectionJobResponseTypeDef = TypedDict(
+    "StopTargetedSentimentDetectionJobResponseTypeDef",
+    {
+        "JobId": str,
+        "JobStatus": JobStatusType,
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
+
 StopTrainingDocumentClassifierRequestRequestTypeDef = TypedDict(
     "StopTrainingDocumentClassifierRequestRequestTypeDef",
     {
@@ -2268,6 +2567,37 @@ class TagTypeDef(_RequiredTagTypeDef, _OptionalTagTypeDef):
     pass
 
 
+TargetedSentimentDetectionJobFilterTypeDef = TypedDict(
+    "TargetedSentimentDetectionJobFilterTypeDef",
+    {
+        "JobName": str,
+        "JobStatus": JobStatusType,
+        "SubmitTimeBefore": Union[datetime, str],
+        "SubmitTimeAfter": Union[datetime, str],
+    },
+    total=False,
+)
+
+TargetedSentimentDetectionJobPropertiesTypeDef = TypedDict(
+    "TargetedSentimentDetectionJobPropertiesTypeDef",
+    {
+        "JobId": str,
+        "JobArn": str,
+        "JobName": str,
+        "JobStatus": JobStatusType,
+        "Message": str,
+        "SubmitTime": datetime,
+        "EndTime": datetime,
+        "InputDataConfig": "InputDataConfigTypeDef",
+        "OutputDataConfig": "OutputDataConfigTypeDef",
+        "LanguageCode": LanguageCodeType,
+        "DataAccessRoleArn": str,
+        "VolumeKmsKeyId": str,
+        "VpcConfig": "VpcConfigTypeDef",
+    },
+    total=False,
+)
+
 TopicsDetectionJobFilterTypeDef = TypedDict(
     "TopicsDetectionJobFilterTypeDef",
     {
